Enum node_maintainer::NassunError
source · pub enum NassunError {
Show 20 variants
MissingVersion(PackageSpec, Version),
PackageSpecError(PackageSpecError),
DirReadError(Error, PathBuf),
GitIoError(Error),
GitCloneError(String),
GitCheckoutError(String, String),
ExtractIoError(Error, Option<PathBuf>, String),
ExtractCacheError(Error, Option<PathBuf>),
IoError(Error),
OroClientError(OroClientError),
SerdeError(Error),
UrlError(ParseError),
IntegrityError(Error),
NoTarball(String, PackageSpec, Box<CorgiVersionMetadata, Global>),
NoVersion {
name: String,
spec: PackageSpec,
versions: Vec<String, Global>,
},
WhichGit(Error),
InvalidPackageSpec(PackageSpec),
UnsupportedDummyOperation(String),
DummyNoName,
MiscError(String),
}Expand description
Error type returned by all API calls.
Variants
MissingVersion(PackageSpec, Version)
Something went wrong while fetching a package.
PackageSpecError(PackageSpecError)
Something went wrong while trying to parse a PackageArg
DirReadError(Error, PathBuf)
GitIoError(Error)
GitCloneError(String)
GitCheckoutError(String, String)
ExtractIoError(Error, Option<PathBuf>, String)
ExtractCacheError(Error, Option<PathBuf>)
IoError(Error)
OroClientError(OroClientError)
SerdeError(Error)
UrlError(ParseError)
IntegrityError(Error)
NoTarball(String, PackageSpec, Box<CorgiVersionMetadata, Global>)
NoVersion
WhichGit(Error)
InvalidPackageSpec(PackageSpec)
UnsupportedDummyOperation(String)
DummyNoName
MiscError(String)
A miscellaneous, usually internal error. This is used mainly to wrap either manual InternalErrors, or those using external errors that don’t implement std::error::Error.