pub enum NodeMaintainerError {
Show 26 variants
UnsupportedScheme(String),
UrlParseError(String, ParseError),
SemverParseError(SemverError),
MissingVersion,
MissingResolution,
IntegrityParseError(Error),
KdlLockfileIntegrityParseError(KdlNode, Error),
KdlLockMissingName(KdlNode),
NpmLockMissingName(Box<NpmPackageLockEntry>),
NpmLockfileIntegrityParseError(Box<NpmPackageLockEntry>, Error),
NpmUnsupportedPackageLockVersion(u64),
KdlLockMissingRoot(KdlDocument),
NpmLockMissingRoot(NpmPackageLock),
KdlParseError(KdlError),
InvalidLockfileVersion,
PackageSpecError(PackageSpecError),
IoError(String, Error),
NassunError(NassunError),
SerdeJsonError(Error),
MiscError(String),
TrySendError,
GraphValidationError(String),
WalkDirError(Error),
BuildManifestReadError(PathBuf, Error),
OroScriptError(OroScriptError),
LockfileMismatch,
}Variants
UnsupportedScheme(String)
Unsupported resolved URL scheme
UrlParseError(String, ParseError)
Failed to parse a resolved URL while parsing lockfile
SemverParseError(SemverError)
Failed to parse a Semver string.
MissingVersion
Missing version for NPM package entry in lockfile.
MissingResolution
Missing resolution for package entry in lockfile.
IntegrityParseError(Error)
Failed to parse an integrity value.
KdlLockfileIntegrityParseError(KdlNode, Error)
Failed to parse an integrity value while loading lockfile.
KdlLockMissingName(KdlNode)
Missing package node name.
NpmLockMissingName(Box<NpmPackageLockEntry>)
Missing package node name.
NpmLockfileIntegrityParseError(Box<NpmPackageLockEntry>, Error)
Failed to parse an integrity value while loading NPM lockfile.
NpmUnsupportedPackageLockVersion(u64)
Unsupported NPM Package Lock version.
KdlLockMissingRoot(KdlDocument)
No root node in KDL lockfile.
NpmLockMissingRoot(NpmPackageLock)
No root node in NPM lockfile.
KdlParseError(KdlError)
Error parsing lockfile.
InvalidLockfileVersion
PackageSpecError(PackageSpecError)
Generic package spec error.
IoError(String, Error)
Generic IO Error.
NassunError(NassunError)
Generic error returned from Nassun.
SerdeJsonError(Error)
Generic serde_json error.
MiscError(String)
Generic error. Refer to the error message for more details.
TrySendError
Failed to send data through mpsc channel. This is likely an internal error of some sort.
GraphValidationError(String)
Failed to validate a graph. Refer to the error message for more details.
WalkDirError(Error)
Got an error while walking node_modules. Refer to the error message
for specific details.
BuildManifestReadError(PathBuf, Error)
Failed to read package.json during the build step. Refer to the
error message for more details.
OroScriptError(OroScriptError)
Some error occurred while running a script. Refer to the error message for more details.
LockfileMismatch
Locked file was requested, but a new dependency tree was resolved that
would cause changes to the lockfile. The contents of package.json
may have changed since the last time the lockfile was updated.
This typically happens when a dependency is added or removed from package.json while locked mode is enabled. If you have an existing lockfile and get this error without any modifications to package.json, please report this as a bug.