pub enum NodeMaintainerError {
Show 24 variants UnsupportedScheme(String), UrlParseError(String, ParseError), SemverParseError(SemverError), MissingVersion, MissingResolution, IntegrityParseError(Error), KdlLockfileIntegrityParseError(KdlNode, Error), KdlLockMissingName(KdlNode), NpmLockMissingName(NpmPackageLockEntry), NpmLockfileIntegrityParseError(NpmPackageLockEntry, Error), NpmUnsupportedPackageLockVersion(u64), KdlLockMissingRoot(KdlDocument), NpmLockMissingRoot(NpmPackageLock), KdlParseError(KdlError), InvalidLockfileVersion, PackageSpecError(PackageSpecError), IoError(Error), NassunError(NassunError), SerdeJsonError(Error), MiscError(String), TrySendError, GraphValidationError(String), WalkDirError(Error), BuildManifestReadError(PathBuf, Error),
}

Variants



UnsupportedScheme(String)

Unsupported resolved URL scheme



UrlParseError(String, ParseError)

Failed to parse a resolved URL while parsing lockfile



SemverParseError(SemverError)

Failed to parse a Semver string.



MissingVersion

Missing version for NPM package entry in lockfile.



MissingResolution

Missing resolution for package entry in lockfile.



IntegrityParseError(Error)

Failed to parse an integrity value.



KdlLockfileIntegrityParseError(KdlNode, Error)

Failed to parse an integrity value while loading lockfile.



KdlLockMissingName(KdlNode)

Missing package node name.



NpmLockMissingName(NpmPackageLockEntry)

Missing package node name.



NpmLockfileIntegrityParseError(NpmPackageLockEntry, Error)

Failed to parse an integrity value while loading NPM lockfile.



NpmUnsupportedPackageLockVersion(u64)

Unsupported NPM Package Lock version.



KdlLockMissingRoot(KdlDocument)

No root node in KDL lockfile.



NpmLockMissingRoot(NpmPackageLock)

No root node in NPM lockfile.



KdlParseError(KdlError)

Error parsing lockfile.



InvalidLockfileVersion



PackageSpecError(PackageSpecError)

Generic package spec error.



IoError(Error)

Generic IO Error.



NassunError(NassunError)

Generic error returned from Nassun.



SerdeJsonError(Error)

Generic serde_json error.



MiscError(String)

Generic error



TrySendError



GraphValidationError(String)



WalkDirError(Error)



BuildManifestReadError(PathBuf, Error)