Struct node_maintainer::NassunOpts
source · pub struct NassunOpts { /* private fields */ }Expand description
Build a new Nassun instance with specified options.
Implementations
sourceimpl NassunOpts
impl NassunOpts
pub fn new() -> NassunOpts
sourcepub fn cache(self, cache: impl AsRef<Path>) -> NassunOpts
pub fn cache(self, cache: impl AsRef<Path>) -> NassunOpts
Cache directory to use for requests.
pub fn registry(self, registry: Url) -> NassunOpts
sourcepub fn scope_registry(self, scope: impl AsRef<str>, registry: Url) -> NassunOpts
pub fn scope_registry(self, scope: impl AsRef<str>, registry: Url) -> NassunOpts
Adds a registry to use for a specific scope.
sourcepub fn base_dir(self, base_dir: impl AsRef<Path>) -> NassunOpts
pub fn base_dir(self, base_dir: impl AsRef<Path>) -> NassunOpts
Base directory to use for resolving relative paths. Defaults to ".".
sourcepub fn default_tag(self, default_tag: impl AsRef<str>) -> NassunOpts
pub fn default_tag(self, default_tag: impl AsRef<str>) -> NassunOpts
Default tag to use when resolving package versions. Defaults to latest.
sourcepub fn memoize_metadata(self, memoize: bool) -> NassunOpts
pub fn memoize_metadata(self, memoize: bool) -> NassunOpts
Whether to memoize package metadata. This will keep any processed
packuments in memory for the lifetime of this Nassun instance.
Setting this to true may increase performance when fetching many
packages, at the cost of significant additional memory usage.
pub fn proxy(self, proxy: bool) -> NassunOpts
pub fn proxy_url(self, proxy_url: impl AsRef<str>) -> NassunOpts
pub fn no_proxy_domain(self, no_proxy_domain: impl AsRef<str>) -> NassunOpts
pub fn fetch_retries(self, fetch_retries: u32) -> NassunOpts