pub struct NassunOpts { /* private fields */ }
Build a new Nassun instance with specified options.

Implementations

source

impl NassunOpts

source

pub fn new() -> NassunOpts

source

pub fn cache(self, cache: impl AsRef<Path>) -> NassunOpts

Cache directory to use for requests.

source

pub fn registry(self, registry: Url) -> NassunOpts

source

pub fn scope_registry(self, scope: impl AsRef<str>, registry: Url) -> NassunOpts

Adds a registry to use for a specific scope.

source

pub fn base_dir(self, base_dir: impl AsRef<Path>) -> NassunOpts

Base directory to use for resolving relative paths. Defaults to ".".

source

pub fn default_tag(self, default_tag: impl AsRef<str>) -> NassunOpts

Default tag to use when resolving package versions. Defaults to latest.

source

pub fn memoize_metadata(self, memoize: bool) -> NassunOpts

Whether to memoize package metadata. This will keep any processed packuments in memory for the lifetime of this Nassun instance. Setting this to true may increase performance when fetching many packages, at the cost of significant additional memory usage.

source

pub fn build(self) -> Nassun

Build a new Nassun instance from this options object.