Struct node_maintainer::NodeMaintainerOptions
source · pub struct NodeMaintainerOptions { /* private fields */ }Implementations
sourceimpl NodeMaintainerOptions
impl NodeMaintainerOptions
pub fn new() -> Self
pub fn progress_bar(self, progress_bar: bool) -> Self
pub fn cache(self, cache: impl AsRef<Path>) -> Self
pub fn parallelism(self, parallelism: usize) -> Self
pub fn kdl_lock( self, kdl_lock: impl IntoKdl ) -> Result<Self, NodeMaintainerError>
pub fn npm_lock( self, npm_lock: impl AsRef<str> ) -> Result<Self, NodeMaintainerError>
pub fn registry(self, registry: Url) -> Self
pub fn scope_registry(self, scope: impl AsRef<str>, registry: Url) -> Self
pub fn base_dir(self, path: impl AsRef<Path>) -> Self
pub fn default_tag(self, tag: impl AsRef<str>) -> Self
sourcepub fn prefer_copy(self, prefer_copy: bool) -> Self
pub fn prefer_copy(self, prefer_copy: bool) -> Self
When extracting tarballs, prefer to copy files to their destination as separate, standalone files instead of hard linking them. Full copies will still happen when hard linking fails. Furthermore, on filesystems that support Copy-on-Write (zfs, btrfs, APFS (macOS), etc), this option will use that feature for all copies.
pub async fn resolve_manifest( self, root: CorgiManifest ) -> Result<NodeMaintainer, NodeMaintainerError>
pub async fn resolve_spec( self, root_spec: impl AsRef<str> ) -> Result<NodeMaintainer, NodeMaintainerError>